@@ -13,7 +13,7 @@ and then acts upon those files.
 """
 import os
 import logging
-import pygit2
+from edk2toolext.environment import repo_resolver
 from edk2toolext.environment import shell_environment
 from edk2toolext.environment import environment_descriptor_files as EDF
 from edk2toolext.environment import external_dependency
@@ -48,12 +48,9 @@ class self_describing_environment(object):
         self.skipped_dirs = tuple(map(Path, (os.path.join(self.workspace, d) for d in skipped_dirs)))
 
         # Respect git worktrees
-        repo_path = pygit2.discover_repository(self.workspace)
-        if repo_path:
-            repo = pygit2.Repository(repo_path)
-            worktrees = repo.list_worktrees()
-            for worktree in worktrees:
-                worktree_path = Path(repo.lookup_worktree(worktree).path)
+        details = repo_resolver.repo_details(self.workspace)
+        if details["Valid"]:
+            for worktree_path in details["Worktrees"]:
                 if (worktree_path.is_dir()
                         and Path(self.workspace) != worktree_path
                         and worktree_path not in skipped_dirs):
